pub struct TPMAuthPolicy {
pub name: Option<Utf8String>,
pub policy: SequenceOf<TPMPolicy>,
}Fields
name: Option<Utf8String>An optional string name for the current policy which is only used for display purposes, MAY be used as a user visible mnemonic for the actual policy.
policy: SequenceOf<TPMPolicy>A sequence of TPMPolicy statements which MUST end with a PolicyAuthorize statement whose signature is over the hash of the current policy excluding the PolicyAuthorize statement and the nonce specified at the beginning of the TPMKey policy. There MUST be no other TPM2_PolicyAuthorize statements in the intermediate policy steps. There MAY be an initial TPM2_PolicyAuthorize statement containing a different public key (because this causes complexity building signed policy chains, implementations MAY choose to allow only a single policy signing key, in which case there MAY NOT be an initial TPM2_PolicyAuthorize statement).