pub struct TPMPolicy {
pub command_code: u32,
pub command_policy: OctetString,
}Fields
command_code: u32This is the integer representation of the TPM command code for the policy statement.
command_policy: OctetStringThis is a binary string representing a fully marshalled, TPM ordered, command body for the TPM policy command. Therefore to send the command, the implementation simply marshals the command code and appends this octet string as the body.
Commands which have no body, such as TPM2_AuthVal, MUST be specified as a zero length OCTET STRING
Note that there are some commands for which the simple body of the TPM policy command does not provide enough information to execute the policy command. A classic example is TPM2_PolicyAuthorize, whose body consists of a key name, a policyRef nonce and a signature. However, the implementation needs to know the actual key, not just the name, to implement the policy