pub struct RasnEncodeError {
pub kind: Box<EncodeErrorKind>,
pub codec: Codec,
}Expand description
An error type for failed encoding for every encoder. Abstracts over the different generic and codec-specific errors.
kind field is used to determine the kind of error that occurred.
codec field is used to determine the codec that failed.
backtrace field is used to determine the backtrace of the error.
There is Kind::CodecSpecific variant which wraps the codec-specific
errors as CodecEncodeError type.
Example
use rasn::{Codec, error::{EncodeErrorKind, strings::PermittedAlphabetError}, prelude::*};
#[derive(AsnType, Clone, Debug, Decode, Encode, PartialEq)]
#[rasn(delegate, from("a..z"))]
struct MyConstrainedString (
VisibleString,
);
// Below sample requires that `backtraces` feature is enabled
let constrained_str = MyConstrainedString(VisibleString::try_from("abcD").unwrap());
let encoded = Codec::Uper.encode_to_binary(&constrained_str);
match encoded {
Ok(succ) => {
println!("Successful encoding!");
dbg!(succ);
}
Err(e) => {
// e is EncodeError, Kind is boxed
match *e.kind {
EncodeErrorKind::AlphabetConstraintNotSatisfied {
reason: PermittedAlphabetError::CharacterNotFound {character },
} => {
println!("Codec: {}", e.codec);
println!("Character {} not found from the permitted list.",
char::from_u32(character).unwrap());
#[cfg(feature = "backtraces")]
println!("Backtrace:\n{}", e.backtrace);
}
_ => {
panic!("Unexpected error!");
}
}
}
}
// Should print ->
//
// Codec: UPER
// Character D not found from the permitted list.
// Backtrace: ...Fields
kind: Box<EncodeErrorKind>The inner encoding error.
codec: CodecThe codec associated with the error.
Implementations
Sourceimpl EncodeError
impl EncodeError
Sourcepub fn alphabet_constraint_not_satisfied(
reason: PermittedAlphabetError,
codec: Codec,
) -> EncodeError
pub fn alphabet_constraint_not_satisfied( reason: PermittedAlphabetError, codec: Codec, ) -> EncodeError
Returns an encode error for codec when the alphabet constraint is not satisfied.
Sourcepub fn size_constraint_not_satisfied(
size: usize,
expected: &Size,
codec: Codec,
) -> EncodeError
pub fn size_constraint_not_satisfied( size: usize, expected: &Size, codec: Codec, ) -> EncodeError
Returns an encode error for codec when the size constraint is not satisfied.
The size is the actual size that failed the constraint and expected the expected size.
Sourcepub fn value_constraint_not_satisfied(
value: BigInt,
expected: &Bounded<i128>,
codec: Codec,
) -> EncodeError
pub fn value_constraint_not_satisfied( value: BigInt, expected: &Bounded<i128>, codec: Codec, ) -> EncodeError
Returns an encode error for codec when the value constraint is not satisfied.
The value is the actual value that failed the constraint.
Sourcepub fn check_length(
length: usize,
expected: &Size,
codec: Codec,
) -> Result<(), EncodeError>
pub fn check_length( length: usize, expected: &Size, codec: Codec, ) -> Result<(), EncodeError>
Check the passed length against the expected size and return an error if it does not match.
Sourcepub fn length_exceeds_platform_size(codec: Codec) -> EncodeError
pub fn length_exceeds_platform_size(codec: Codec) -> EncodeError
Create an encode error for codec when the value is too large to be encoded on the current platform.
Sourcepub fn integer_type_conversion_failed(msg: String, codec: Codec) -> EncodeError
pub fn integer_type_conversion_failed(msg: String, codec: Codec) -> EncodeError
Create an error for failed conversion from BitInt or BigUint to primitive integer types
Sourcepub fn opaque_conversion_failed(msg: String, codec: Codec) -> EncodeError
pub fn opaque_conversion_failed(msg: String, codec: Codec) -> EncodeError
Create an error if conversion to opaque type failed.
This is mainly used as part of SMI standard which converts type to BER encoding and handles bytes as Opaque.
Sourcepub fn variant_not_in_choice(codec: Codec) -> EncodeError
pub fn variant_not_in_choice(codec: Codec) -> EncodeError
Create an error when the selected variant is not found in the choice.
Sourcepub fn real_not_supported(codec: Codec) -> EncodeError
pub fn real_not_supported(codec: Codec) -> EncodeError
Returns an encode error when the encoder doesn’t support REAL type.
Sourcepub fn from_kind(kind: EncodeErrorKind, codec: Codec) -> EncodeError
pub fn from_kind(kind: EncodeErrorKind, codec: Codec) -> EncodeError
A helper function to construct an EncodeError from the given kind and codec.